@@ -1,7 +1,7 @@
 package Getopt::Long::Util;
 
-our $DATE = '2016-10-26'; # DATE
-our $VERSION = '0.86'; # VERSION
+our $DATE = '2016-10-27'; # DATE
+our $VERSION = '0.87'; # VERSION
 
 use 5.010001;
 use strict;
@@ -198,20 +198,12 @@ _
         filename => {
             summary => 'Path to file to be checked',
             schema => 'str*',
-            description => <<'_',
-
-Either `filename` or `string` must be specified.
-
-_
+            pos => 0,
+            cmdline_aliases => {f=>{}},
         },
         string => {
             summary => 'Path to file to be checked',
             schema => 'buf*',
-            description => <<'_',
-
-Either `file` or `string` must be specified.
-
-_
         },
         include_noexec => {
             summary => 'Include scripts that do not have +x mode bit set',
@@ -219,6 +211,9 @@ _
             default => 1,
         },
     },
+    args_rels => {
+        'req_one' => ['filename', 'string'],
+    },
 };
 sub detect_getopt_long_script {
     my %args = @_;
@@ -312,7 +307,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.86 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-10-26.
+This document describes version 0.87 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-10-27.
 
 =head1 FUNCTIONS
 
@@ -347,8 +342,6 @@ Arguments ('*' denotes required arguments):
 
 Path to file to be checked.
 
-Either C<filename> or C<string> must be specified.
-
 =item * B<include_noexec> => I<bool> (default: 1)
 
 Include scripts that do not have +x mode bit set.
@@ -357,8 +350,6 @@ Include scripts that do not have +x mode bit set.
 
 Path to file to be checked.
 
-Either C<file> or C<string> must be specified.
-
 =back
 
 Returns an enveloped result (an array).
